==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/TemplateListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TemplateListBuilder extends TemplateListFluentImpl<TemplateListBuilder> implements VisitableBuilder<TemplateList,TemplateListBuilder>{
  public TemplateListBuilder() {
    this(false);
  }
  public TemplateListBuilder(Boolean validationEnabled) {
    this(new TemplateList(), validationEnabled);
  }
  public TemplateListBuilder(TemplateListFluent<?> fluent) {
    this(fluent, false);
  }
  public TemplateListBuilder(TemplateListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TemplateList(), validationEnabled);
  }
  public TemplateListBuilder(TemplateListFluent<?> fluent,TemplateList instance) {
    this(fluent, instance, false);
  }
  public TemplateListBuilder(TemplateListFluent<?> fluent,TemplateList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public TemplateListBuilder(TemplateList instance) {
    this(instance,false);
  }
  public TemplateListBuilder(TemplateList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  TemplateListFluent<?> fluent;
  Boolean validationEnabled;
  public TemplateList build() {
    TemplateList buildable = new TemplateList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.1-sources.jar: io/fabric8/openshift/api/model/TemplateListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TemplateListBuilder extends TemplateListFluent<TemplateListBuilder> implements VisitableBuilder<TemplateList,TemplateListBuilder>{
  public TemplateListBuilder() {
    this(false);
  }
  public TemplateListBuilder(Boolean validationEnabled) {
    this(new TemplateList(), validationEnabled);
  }
  public TemplateListBuilder(TemplateListFluent<?> fluent) {
    this(fluent, false);
  }
  public TemplateListBuilder(TemplateListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TemplateList(), validationEnabled);
  }
  public TemplateListBuilder(TemplateListFluent<?> fluent,TemplateList instance) {
    this(fluent, instance, false);
  }
  public TemplateListBuilder(TemplateListFluent<?> fluent,TemplateList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new TemplateList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public TemplateListBuilder(TemplateList instance) {
    this(instance,false);
  }
  public TemplateListBuilder(TemplateList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new TemplateList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  TemplateListFluent<?> fluent;
  Boolean validationEnabled;
  public TemplateList build() {
    TemplateList buildable = new TemplateList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
